@@ -1,4 +1,4 @@
-import vg
+from vg.compat import v2 as vg
 from ._analysis.analysis_mixin import AnalysisMixin
 from ._common.validation import check_arity, check_indices
 from ._obj.writer import write as write_obj
@@ -39,11 +39,6 @@ class Mesh(AnalysisMixin, SelectionMixin, TransformMixin):
         self.v = v
         self.face_groups = face_groups
 
-    # TODO: Needs coverage.
-    # @classmethod
-    # def from_lace(cls, mesh):
-    #     return cls(v=mesh.v, f=mesh.f)
-
     # TODO: Needs coverage.
     # @classmethod
     # def from_trimesh(cls, mesh):
